==> zio-aws-appconfigdata_3-5.17.295.6-sources.jar: zio/aws/appconfigdata/model/GetLatestConfigurationResponse.scala <==
package zio.aws.appconfigdata.model
import zio.aws.appconfigdata.model.primitives.{
  SyntheticGetLatestConfigurationResponseBlob,
  Integer,
  Token
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetLatestConfigurationResponse(
    nextPollConfigurationToken: Optional[Token] = Optional.Absent,
    nextPollIntervalInSeconds: Optional[Integer] = Optional.Absent,
    contentType: Optional[String] = Optional.Absent,
    configuration: Optional[SyntheticGetLatestConfigurationResponseBlob] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse = {
    import GetLatestConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
      .builder()
      .optionallyWith(
        nextPollConfigurationToken.map(value =>
          Token.unwrap(value): java.lang.String
        )
      )(_.nextPollConfigurationToken)
      .optionallyWith(
        nextPollIntervalInSeconds.map(value => value: java.lang.Integer)
      )(_.nextPollIntervalInSeconds)
      .optionallyWith(contentType.map(value => value: java.lang.String))(
        _.contentType
      )
      .optionallyWith(
        configuration.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.configuration)
      .build()
  }
  def asReadOnly
      : zio.aws.appconfigdata.model.GetLatestConfigurationResponse.ReadOnly =
    zio.aws.appconfigdata.model.GetLatestConfigurationResponse
      .wrap(buildAwsValue())
}
object GetLatestConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appconfigdata.model.GetLatestConfigurationResponse =
      zio.aws.appconfigdata.model.GetLatestConfigurationResponse(
        nextPollConfigurationToken.map(value => value),
        nextPollIntervalInSeconds.map(value => value),
        contentType.map(value => value),
        configuration.map(value => value)
      )
    def nextPollConfigurationToken: Optional[Token]
    def nextPollIntervalInSeconds: Optional[Integer]
    def contentType: Optional[String]
    def configuration: Optional[SyntheticGetLatestConfigurationResponseBlob]
    def getNextPollConfigurationToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField(
        "nextPollConfigurationToken",
        nextPollConfigurationToken
      )
    def getNextPollIntervalInSeconds: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("nextPollIntervalInSeconds", nextPollIntervalInSeconds)
    def getContentType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getConfiguration
        : ZIO[Any, AwsError, SyntheticGetLatestConfigurationResponseBlob] =
      AwsError.unwrapOptionField("configuration", configuration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
  ) extends zio.aws.appconfigdata.model.GetLatestConfigurationResponse.ReadOnly {
    override val nextPollConfigurationToken: Optional[Token] =
      zio.aws.core.internal
        .optionalFromNullable(impl.nextPollConfigurationToken())
        .map(value => zio.aws.appconfigdata.model.primitives.Token(value))
    override val nextPollIntervalInSeconds: Optional[Integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.nextPollIntervalInSeconds())
        .map(value => value: Integer)
    override val contentType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.contentType())
      .map(value => value: String)
    override val configuration
        : Optional[SyntheticGetLatestConfigurationResponseBlob] =
      zio.aws.core.internal
        .optionalFromNullable(impl.configuration())
        .map(value =>
          zio.aws.appconfigdata.model.primitives
            .SyntheticGetLatestConfigurationResponseBlob(
              zio.Chunk.fromArray(value.asByteArrayUnsafe())
            )
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
  ): zio.aws.appconfigdata.model.GetLatestConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-appconfigdata_3-7.21.15.3-sources.jar: zio/aws/appconfigdata/model/GetLatestConfigurationResponse.scala <==
package zio.aws.appconfigdata.model
import zio.aws.appconfigdata.model.primitives.{SensitiveBlob, Integer, Token}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetLatestConfigurationResponse(
    nextPollConfigurationToken: Optional[Token] = Optional.Absent,
    nextPollIntervalInSeconds: Optional[Integer] = Optional.Absent,
    contentType: Optional[String] = Optional.Absent,
    configuration: Optional[SensitiveBlob] = Optional.Absent,
    versionLabel: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse = {
    import GetLatestConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
      .builder()
      .optionallyWith(
        nextPollConfigurationToken.map(value =>
          Token.unwrap(value): java.lang.String
        )
      )(_.nextPollConfigurationToken)
      .optionallyWith(
        nextPollIntervalInSeconds.map(value => value: java.lang.Integer)
      )(_.nextPollIntervalInSeconds)
      .optionallyWith(contentType.map(value => value: java.lang.String))(
        _.contentType
      )
      .optionallyWith(
        configuration.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.configuration)
      .optionallyWith(versionLabel.map(value => value: java.lang.String))(
        _.versionLabel
      )
      .build()
  }
  def asReadOnly
      : zio.aws.appconfigdata.model.GetLatestConfigurationResponse.ReadOnly =
    zio.aws.appconfigdata.model.GetLatestConfigurationResponse
      .wrap(buildAwsValue())
}
object GetLatestConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appconfigdata.model.GetLatestConfigurationResponse =
      zio.aws.appconfigdata.model.GetLatestConfigurationResponse(
        nextPollConfigurationToken.map(value => value),
        nextPollIntervalInSeconds.map(value => value),
        contentType.map(value => value),
        configuration.map(value => value),
        versionLabel.map(value => value)
      )
    def nextPollConfigurationToken: Optional[Token]
    def nextPollIntervalInSeconds: Optional[Integer]
    def contentType: Optional[String]
    def configuration: Optional[SensitiveBlob]
    def versionLabel: Optional[String]
    def getNextPollConfigurationToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField(
        "nextPollConfigurationToken",
        nextPollConfigurationToken
      )
    def getNextPollIntervalInSeconds: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("nextPollIntervalInSeconds", nextPollIntervalInSeconds)
    def getContentType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getConfiguration: ZIO[Any, AwsError, SensitiveBlob] =
      AwsError.unwrapOptionField("configuration", configuration)
    def getVersionLabel: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("versionLabel", versionLabel)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
  ) extends zio.aws.appconfigdata.model.GetLatestConfigurationResponse.ReadOnly {
    override val nextPollConfigurationToken: Optional[Token] =
      zio.aws.core.internal
        .optionalFromNullable(impl.nextPollConfigurationToken())
        .map(value => zio.aws.appconfigdata.model.primitives.Token(value))
    override val nextPollIntervalInSeconds: Optional[Integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.nextPollIntervalInSeconds())
        .map(value => value: Integer)
    override val contentType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.contentType())
      .map(value => value: String)
    override val configuration: Optional[SensitiveBlob] = zio.aws.core.internal
      .optionalFromNullable(impl.configuration())
      .map(value =>
        zio.aws.appconfigdata.model.primitives
          .SensitiveBlob(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val versionLabel: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.versionLabel())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.appconfigdata.model.GetLatestConfigurationResponse
  ): zio.aws.appconfigdata.model.GetLatestConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}
